==> service-common-2.10.1-20161201.064345-4-sources.jar: com/baijia/tianxiao/dto/smstoken/StudentSmsTokenDto.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2015-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.dto.smstoken;


import java.util.Map;

import com.baijia.tianxiao.util.CourseSmsTokenUtil;
import com.baijia.tianxiao.util.CourseSmsTokenUtil.SmsToken;

import lombok.Data;

/**   
 * @title       : WechatSmsTokenDto 
 * @description : 
 * @author      : zhenyujian
 * @date        : 2016年9月1日 下午7:58:36 
 */
@Data
public class StudentSmsTokenDto extends SmsTokenDto{
	 private Long orgId;
	 private String wechatAppId;
	 private Long studentId;
	 private String openId;
	
	 private StudentSmsTokenDto (){
	 }
	
	 public StudentSmsTokenDto(Long orgId, String wechatAppId, Long studentId, String openId){
		 this.orgId = orgId;
		 this.wechatAppId = wechatAppId;
		 this.studentId = studentId;
		 this.openId = openId;
	 }

	public static StudentSmsTokenDto fromTokenStr(String tokenStr) throws Exception {
		StudentSmsTokenDto obj = new StudentSmsTokenDto();
		SmsToken token = CourseSmsTokenUtil.decodeToken(tokenStr);
		Map<String, Object> map = token.getParams();
		
		obj.setOrgId( map.get("orgId")!=null ? Long.parseLong(map.get("orgId").toString()) : null );
		obj.setWechatAppId( map.get("wechatAppId")!=null ? map.get("wechatAppId").toString() : null );
		obj.setStudentId( map.get("studentId")!=null ? Long.parseLong(map.get("studentId").toString()) : null );
		obj.setOpenId( map.get("openId")!=null ? map.get("openId").toString() : null );
		
		return obj;
	}
	
	public static void main(String args[]) throws Exception{
		String a ="En0kdnUkPDM2OTU2Mzs7OzI5MjwvJXJ1akxnJT03MzQ5LyVzZHZlcXcmPn8md3h5aGlyeE1oJj84PDg7PDoxJ3R1anNOaSc_J3U2a3RufHOAcX9PXlROZWs3dFNzbXVuPmpIfX4pMyl2eW5QaypCPDg5PjQqf21rcGl8SXh4UW0rQyuAgTlrPG5COkI_O29APTs9PDoshzYsgG98fXN5eCxEO4g";
//		String a1="LH8meHcmPjU4OzY9Ozs2Nzc6OjUwJnN2a01oJj43OjU8MCZ0ZXZlcXcmPn8mdHdsTmknPzg7Nj0xJ3xqaG1meUZ1dU5pJz8nfH01ZzhqPjY-OzdrPDk2ODc2KDIoeXp7amt0ek9qKEA5Oz83NzsyKHV2a3RPaihAKHU2a3RufHOAcX9PXlVPZmw4dVNzbXVuPmpIfX4phDMpfWx5enB2dSlBOIQ?sms_token=E34ld3YlPTQ3OjU8Ojo1NjMzOTYwJnN2a01oJj43OjU8MCZ0ZXZlcngnP4AndHdsTmknPzg7Nj0xJ31raW5nekd2dk9qKEAofX42aDlsQDhAPTltPjs4Ojk3KYQzKX1sentxd3YqQjmF";
//		StudentSmsTokenDto dto = new StudentSmsTokenDto(12345L, "hsfjkshfkjhskhfkhsjdfswq", 222L, "hsfjkshfkjhskhfkhsjdfswq");
//		System.out.println(dto.toTokenStr());
		System.out.println(CourseSmsTokenUtil.decodeToken(a));
	}
}

==> service-common-2.30.0-20170726.074316-36-sources.jar: com/baijia/tianxiao/dto/smstoken/StudentSmsTokenDto.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2015-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.dto.smstoken;


import java.util.Map;

import com.baijia.tianxiao.util.CourseSmsTokenUtil;
import com.baijia.tianxiao.util.CourseSmsTokenUtil.SmsToken;

import lombok.Data;

/**   
 * @title       : WechatSmsTokenDto 
 * @description : 
 * @author      : zhenyujian
 * @date        : 2016年9月1日 下午7:58:36 
 */
@Data
public class StudentSmsTokenDto extends SmsTokenDto{
	 private Long orgId;
	 private String wechatAppId;
	 private Long studentId;
	 private String openId;
	
	 private StudentSmsTokenDto (){
	 }
	
	 public StudentSmsTokenDto(Long orgId, String wechatAppId, Long studentId, String openId){
		 this.orgId = orgId;
		 this.wechatAppId = wechatAppId;
		 this.studentId = studentId;
		 this.openId = openId;
	 }

	public static StudentSmsTokenDto fromTokenStr(String tokenStr) throws Exception {
		StudentSmsTokenDto obj = new StudentSmsTokenDto();
		SmsToken token = CourseSmsTokenUtil.decodeToken(tokenStr);
		Map<String, Object> map = token.getParams();
		
		obj.setOrgId( map.get("orgId")!=null ? Long.parseLong(map.get("orgId").toString()) : null );
		obj.setWechatAppId( map.get("wechatAppId")!=null ? map.get("wechatAppId").toString() : null );
		obj.setStudentId( map.get("studentId")!=null ? Long.parseLong(map.get("studentId").toString()) : null );
		obj.setOpenId( map.get("openId")!=null ? map.get("openId").toString() : null );
		
		return obj;
	}
	
	public static void main(String args[]) throws Exception{
		String a ="In0kdnUkPDM2OzI0Nzk0Mjk3OzUuJHF0aUtmJDw2ODg1My4lc2R1ZHB2JT1-JXZ3eGdocXdMZyU9NTk7Nzg0Oi8lcnNock1oJj4mc2c3OXN8SXpROXhGODZseG98XG1Ic1lTejExbycxJ3R3bE5pJz85Ozs4NjEnfGpobWZ5RnV1TmknPyd8fWhsPms8aGloNzw4Zz48Zz0ogzIofGt4eW91dChAN4M";
//		String a1="LH8meHcmPjU4OzY9Ozs2Nzc6OjUwJnN2a01oJj43OjU8MCZ0ZXZlcXcmPn8mdHdsTmknPzg7Nj0xJ3xqaG1meUZ1dU5pJz8nfH01ZzhqPjY-OzdrPDk2ODc2KDIoeXp7amt0ek9qKEA5Oz83NzsyKHV2a3RPaihAKHU2a3RufHOAcX9PXlVPZmw4dVNzbXVuPmpIfX4phDMpfWx5enB2dSlBOIQ?sms_token=E34ld3YlPTQ3OjU8Ojo1NjMzOTYwJnN2a01oJj43OjU8MCZ0ZXZlcngnP4AndHdsTmknPzg7Nj0xJ31raW5nekd2dk9qKEAofX42aDlsQDhAPTltPjs4Ojk3KYQzKX1sentxd3YqQjmF";
//		StudentSmsTokenDto dto = new StudentSmsTokenDto(12345L, "hsfjkshfkjhskhfkhsjdfswq", 222L, "hsfjkshfkjhskhfkhsjdfswq");
//		System.out.println(dto.toTokenStr());
		System.out.println(CourseSmsTokenUtil.decodeToken(a));
	}
}
